@@ -1,6 +1,9 @@
+from __future__ import unicode_literals, absolute_import
 from datetime import date, timedelta
 from calendar import monthrange
 
+from django.utils.six.moves import xrange
+
 
 def diff(a, b):
     return list(set(a) - set(b))
